summaryrefslogtreecommitdiff
path: root/libs/pbd/sndfile_manager.cc
diff options
context:
space:
mode:
Diffstat (limited to 'libs/pbd/sndfile_manager.cc')
-rw-r--r--libs/pbd/sndfile_manager.cc16
1 files changed, 10 insertions, 6 deletions
diff --git a/libs/pbd/sndfile_manager.cc b/libs/pbd/sndfile_manager.cc
index 5f08e634d6..9838515682 100644
--- a/libs/pbd/sndfile_manager.cc
+++ b/libs/pbd/sndfile_manager.cc
@@ -17,6 +17,10 @@
*/
+/** @file libs/pbd/sndfile_manager.cc
+ * @brief A FileDescriptor for files opened using libsndfile.
+ */
+
#include <sys/time.h>
#include <sys/resource.h>
#include <sys/types.h>
@@ -31,15 +35,15 @@
using namespace std;
using namespace PBD;
/** @param n Filename.
* @param w true to open writeable, otherwise false.
* @param i SF_INFO for the file.
*/
-SndFileDescriptor::SndFileDescriptor (string const & n, bool w, SF_INFO* i)
- : FileDescriptor (n, w)
+SndFileDescriptor::SndFileDescriptor (string const & file_name, bool writeable, SF_INFO* info)
+ : FileDescriptor (file_name, writeable)
, _sndfile (0)
- , _info (i)
+ , _info (info)
{
manager()->add (this);
}
@@ -31,15 +35,15 @@
using namespace std;
using namespace PBD;
-/** @param n Filename.
- * @param w true to open writeable, otherwise false.
- * @param i SF_INFO for the file.
+/** @param file_name Filename.
+ * @param writeable true to open writeable, otherwise false.
+ * @param info SF_INFO for the file.
*/